# cmem-plugin-base

Python base classes for developing eccenca Coporate Memory plugins.

In order to kick-start developing eccenca Corporate Memory Plugins, please check out this project template: https://github.com/eccenca/cmem-plugin-template

